@@ -58,7 +58,7 @@ int levenshteinDistance(const QString &a, const QString &b)
 
     auto v0 = std::make_unique_for_overwrite<int[]>(b.size() + 1);
     auto v1 = std::make_unique_for_overwrite<int[]>(b.size() + 1);
-    std::iota(v0.get(), v0.get() + b.size() - 1, 0);
+    std::iota(v0.get(), v0.get() + b.size(), 0);
 
     for (int i = 0; i < a.size(); ++i) {
         v1[0] = i + 1;
@@ -205,6 +205,7 @@ std::pair<PortalResponse::Response, QVariantMap> continueStartAfterDialog(Screen
     QVariantList outputs;
     QList<WindowRestoreInfo> windows;
     WaylandIntegration::Streams streams;
+    QPointer<ScreenCastSession> guardedSession(session);
     Screencasting::CursorMode cursorMode = Screencasting::CursorMode(session->cursorMode());
     for (const auto &output : std::as_const(selectedOutputs)) {
         WaylandIntegration::Stream stream;
@@ -255,6 +256,10 @@ std::pair<PortalResponse::Response, QVariantMap> continueStartAfterDialog(Screen
         return {PortalResponse::OtherError, {}};
     }
 
+    if (!guardedSession) {
+        return {PortalResponse::OtherError, {}};
+    }
+
     session->setStreams(streams);
     QVariantMap results;
     results.insert(QStringLiteral("streams"), QVariant::fromValue<WaylandIntegration::Streams>(streams));
@@ -351,8 +356,6 @@ void ScreenCastPortal::Start(const QDBusObjectPath &handle,
         }
     }
 
-    message.setDelayedReply(true);
-
     if (valid) {
         std::tie(replyResponse, replyResults) = continueStartAfterDialog(session, selectedOutputs, selectedRegion, selectedWindows, true);
         return;
