@@ -63,7 +63,7 @@ public:
     Q_ENUM(CursorMode)
 
     ScreencastingStream *createOutputStream(QScreen *screen, CursorMode mode);
-    ScreencastingStream *createWindowStream(const QString &uuid, CursorMode mode);
+    ScreencastingStream *createWindowStream(const KWayland::Client::PlasmaWindow *window, CursorMode mode);
     ScreencastingStream *createRegionStream(const QRect &geometry, qreal scale, CursorMode mode);
     ScreencastingStream *createVirtualOutputStream(const QString &name, const QString &description, const QSize &size, qreal scale, CursorMode mode);
 
